ArabicNames
===========


Random arabic name generator


Installation
------------

The script is `available on PyPI`_.  To install with pip::

    pip install ArabicNames


Usage
-----

Names can be used as a command line utility or imported as a Python package.


Python Package Usage
~~~~~~~~~~~~~~~~~~~~
Here are examples of all current features:

.. code-block:: pycon

    >>> import ArabicNames
    >>> names.get_full_name()
    u'Muhtadi El-Alaoui'


License
-------

This project is released under an `MIT License`_.

.. _mit license: https://ahmed.mit-license.org
.. _available on PyPI: http://pypi.python.org/pypi/ArabicNames
